@@ -1,13 +1,14 @@
-from Cocoa import *
-from Quartz import *
-
 import objc
+from objc import super
+import Cocoa
+import Quartz
+
 
 from math import pi as PI
 import random
 
-class DemoView (NSView):
-    _demoNumber = objc.ivar(objc._C_INT)
+class DemoView (Cocoa.NSView):
+    _demoNumber = objc.ivar(type=objc._C_INT)
 
 
     def initWithFrame_(self, frameRect):
@@ -19,10 +20,10 @@ class DemoView (NSView):
         return self
 
     def drawRect_(self, rect):
-        context = NSGraphicsContext.currentContext().graphicsPort()
+        context = Cocoa.NSGraphicsContext.currentContext().graphicsPort()
 
-        CGContextSetGrayFillColor(context, 1.0, 1.0)
-        CGContextFillRect(context, rect)
+        Quartz.CGContextSetGrayFillColor(context, 1.0, 1.0)
+        Quartz.CGContextFillRect(context, rect)
 
         if self._demoNumber == 0:
             rectangles(context, rect)
@@ -37,7 +38,7 @@ class DemoView (NSView):
             circleClipping(context, rect)
 
         else:
-            NSLog("Invalid demo number.")
+            Cocoa.NSLog("Invalid demo number.")
 
     def setDemoNumber_(self, number):
         self._demoNumber = number
@@ -46,25 +47,25 @@ class DemoView (NSView):
 # The various demo functions
 
 def setRandomFillColor(context):
-    CGContextSetRGBFillColor(context,
+    Quartz.CGContextSetRGBFillColor(context,
            random.uniform(0, 1), random.uniform(0, 1),
            random.uniform(0, 1), random.uniform(0, 1))
 
 def setRandomStrokeColor(context):
-    CGContextSetRGBStrokeColor(context,
+    Quartz.CGContextSetRGBStrokeColor(context,
            random.uniform(0, 1), random.uniform(0, 1),
            random.uniform(0, 1), random.uniform(0, 1))
 
 
 def randomPointInRect(rect):
-    return CGPoint(
-        x = random.uniform(CGRectGetMinX(rect), CGRectGetMaxX(rect)),
-        y = random.uniform(CGRectGetMinY(rect), CGRectGetMaxY(rect)))
+    return Quartz.CGPoint(
+        x = random.uniform(Quartz.CGRectGetMinX(rect), Quartz.CGRectGetMaxX(rect)),
+        y = random.uniform(Quartz.CGRectGetMinY(rect), Quartz.CGRectGetMaxY(rect)))
 
 def randomRectInRect(rect):
     p = randomPointInRect(rect)
     q = randomPointInRect(rect)
-    return CGRectMake(p.x, p.y, q.x - p.x, q.y - p.y)
+    return Quartz.CGRectMake(p.x, p.y, q.x - p.x, q.y - p.y)
 
 def rectangles(context, rect):
     # Draw random rectangles (some stroked, some filled).
@@ -72,93 +73,93 @@ def rectangles(context, rect):
     for k in range(20):
         if k % 2 == 0:
             setRandomFillColor(context)
-            CGContextFillRect(context, randomRectInRect(rect))
+            Quartz.CGContextFillRect(context, randomRectInRect(rect))
 
         else:
             setRandomStrokeColor(context)
-            CGContextSetLineWidth(context, 2 + random.randint(0, 10))
-            CGContextStrokeRect(context, randomRectInRect(rect))
+            Quartz.CGContextSetLineWidth(context, 2 + random.randint(0, 10))
+            Quartz.CGContextStrokeRect(context, randomRectInRect(rect))
 
 def circles(context, rect):
     # Draw random circles (some stroked, some filled).
 
     for k in range(20):
         r = randomRectInRect(rect)
-        w = CGRectGetWidth(r)
-        h = CGRectGetHeight(r)
-        CGContextBeginPath(context)
+        w = Quartz.CGRectGetWidth(r)
+        h = Quartz.CGRectGetHeight(r)
+        Quartz.CGContextBeginPath(context)
 
         if w < h:
             v = w
         else:
             v = h
 
-        CGContextAddArc(context,
-                CGRectGetMidX(r), CGRectGetMidY(r),
+        Quartz.CGContextAddArc(context,
+                Quartz.CGRectGetMidX(r), Quartz.CGRectGetMidY(r),
                 v, 0, 2*PI, False)
-        CGContextClosePath(context)
+        Quartz.CGContextClosePath(context)
 
         if k % 2 == 0:
             setRandomFillColor(context)
-            CGContextFillPath(context)
+            Quartz.CGContextFillPath(context)
 
         else:
             setRandomStrokeColor(context)
-            CGContextSetLineWidth(context, 2 + random.randint(0, 10))
-            CGContextStrokePath(context)
+            Quartz.CGContextSetLineWidth(context, 2 + random.randint(0, 10))
+            Quartz.CGContextStrokePath(context)
 
 def bezierPaths(context, rect):
     for k in range(20):
         numberOfSegments = 1 + random.randint(0, 8)
-        CGContextBeginPath(context)
+        Quartz.CGContextBeginPath(context)
         p = randomPointInRect(rect)
-        CGContextMoveToPoint(context, p.x, p.y)
+        Quartz.CGContextMoveToPoint(context, p.x, p.y)
         for j in range(numberOfSegments):
             p = randomPointInRect(rect);
 
             if j % 2 == 0:
-                CGContextAddLineToPoint(context, p.x, p.y)
+                Quartz.CGContextAddLineToPoint(context, p.x, p.y)
 
             else:
                 c1 = randomPointInRect(rect)
                 c2 = randomPointInRect(rect)
-                CGContextAddCurveToPoint(context, c1.x, c1.y,
+                Quartz.CGContextAddCurveToPoint(context, c1.x, c1.y,
                                          c2.x, c2.y, p.x, p.y)
 
         if k % 2 == 0:
             setRandomFillColor(context)
-            CGContextClosePath(context)
-            CGContextFillPath(context)
+            Quartz.CGContextClosePath(context)
+            Quartz.CGContextFillPath(context)
 
         else:
             setRandomStrokeColor(context)
-            CGContextSetLineWidth(context, 2 + random.randint(0, 10))
-            CGContextStrokePath(context)
+            Quartz.CGContextSetLineWidth(context, 2 + random.randint(0, 10))
+            Quartz.CGContextStrokePath(context)
 
 
 def circleClipping(context, rect):
     # Draw a random path through a circular clip.
 
-    w = CGRectGetWidth(rect)
-    h = CGRectGetHeight(rect)
-    CGContextBeginPath(context)
+    w = Quartz.CGRectGetWidth(rect)
+    h = Quartz.CGRectGetHeight(rect)
+    Quartz.CGContextBeginPath(context)
     if w < h:
         v = w
     else:
         v = h
-    CGContextAddArc(context, CGRectGetMidX(rect), CGRectGetMidY(rect),
+    Quartz.CGContextAddArc(context, Quartz.CGRectGetMidX(rect), Quartz.CGRectGetMidY(rect),
                     v/2, 0, 2*PI, False)
-    CGContextClosePath(context)
-    CGContextClip(context)
+    Quartz.CGContextClosePath(context)
+    Quartz.CGContextClip(context)
 
     # Draw something into the clip.
     bezierPaths(context, rect)
 
     # Draw a clip path on top as a black stroked circle.
-    CGContextBeginPath(context)
-    CGContextAddArc(context, CGRectGetMidX(rect), CGRectGetMidY(rect),
+    Quartz.CGContextBeginPath(context)
+    Quartz.CGContextAddArc(context, Quartz.CGRectGetMidX(rect), Quartz.CGRectGetMidY(rect),
                     v/2, 0, 2*PI, False)
-    CGContextClosePath(context)
-    CGContextSetLineWidth(context, 1)
-    CGContextSetRGBStrokeColor(context, 0, 0, 0, 1)
-    CGContextStrokePath(context)
+    Quartz.CGContextClosePath(context)
+    Quartz.CGContextSetLineWidth(context, 1)
+    Quartz.CGContextSetRGBStrokeColor(context, 0, 0, 0, 1)
+    Quartz.CGContextStrokePath(context)
