@@ -9,6 +9,7 @@ import objc
 import AppKit
 
 from Quartz.PDFKit import _metadata
+from Quartz.PDFKit import _PDFKit
 
 sys.modules['Quartz.PDFKit'] = mod = objc.ObjCLazyModule('Quartz.PDFKit',
     "com.apple.PDFKit",
@@ -16,5 +17,9 @@ sys.modules['Quartz.PDFKit'] = mod = objc.ObjCLazyModule('Quartz.PDFKit',
     _metadata.__dict__, None, {
        '__doc__': __doc__,
        '__path__': __path__,
+       '__loader__': globals().get('__loader__', None),
        'objc': objc,
     }, ( AppKit,))
+
+import sys
+del sys.modules['Quartz.PDFKit._metadata']
