@@ -3,11 +3,6 @@ from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 from Quartz.QuartzCore import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCALayerHelper (NSObject):
     def preferredSizeOfLayer_(self, layer): return 1
 
@@ -44,6 +39,11 @@ class TestCALayer (TestCase):
         self.assertIsInstance(kCAOnOrderOut, unicode)
         self.assertIsInstance(kCATransition, unicode)
 
+        self.assertEqual(kCALayerMinXMinYCorner, 1<<0)
+        self.assertEqual(kCALayerMaxXMinYCorner, 1<<1)
+        self.assertEqual(kCALayerMinXMaxYCorner, 1<<2)
+        self.assertEqual(kCALayerMaxXMaxYCorner, 1<<3)
+
 
     @min_os_level('10.5')
     def testMethods(self):
@@ -62,6 +62,7 @@ class TestCALayer (TestCase):
 
         self.assertResultHasType(TestCALayerHelper.preferredSizeOfLayer_, CGSize.__typestr__)
 
+
     @min_os_level('10.6')
     def testMethods10_6(self):
         self.assertResultIsBOOL(CALayer.needsDisplayForKey_)
@@ -74,10 +75,43 @@ class TestCALayer (TestCase):
         self.assertResultIsBOOL(CALayer.needsDisplay)
         self.assertResultIsBOOL(CALayer.needsLayout)
 
+    @min_os_level('10.7')
+    def testMethods10_7(self):
+        self.assertResultIsBOOL(CALayer.shouldRasterize)
+        self.assertArgIsBOOL(CALayer.setShouldRasterize_, 0)
+
+    @min_os_level('10.8')
+    def testMethods10_8(self):
+        self.assertResultIsBOOL(CALayer.drawsAsynchronously)
+        self.assertArgIsBOOL(CALayer.setDrawsAsynchronously_, 0)
+
+    @min_os_level('10.10')
+    def testMethods10_10(self):
+        self.assertResultIsBOOL(CALayer.allowsEdgeAntialiasing)
+        self.assertArgIsBOOL(CALayer.setAllowsEdgeAntialiasing_, 0)
+        self.assertResultIsBOOL(CALayer.allowsGroupOpacity)
+        self.assertArgIsBOOL(CALayer.setAllowsGroupOpacity_, 0)
+
     @min_os_level('10.6')
     def testConstants10_6(self):
         self.assertIsInstance(kCAFilterTrilinear, unicode)
 
+    @min_os_level('10.12')
+    def testConstants10_12(self):
+        self.assertIsInstance(kCAContentsFormatRGBA8Uint, unicode)
+        self.assertIsInstance(kCAContentsFormatRGBA16Float, unicode)
+        self.assertIsInstance(kCAContentsFormatGray8Uint, unicode)
+
+    @min_sdk_level('10.6')
+    def testProtocols(self):
+        objc.protocolNamed('CAAction')
+
+    @min_sdk_level('10.12')
+    def testProtocols(self):
+        objc.protocolNamed("CALayerDelegate")
+        objc.protocolNamed("CALayoutManager")
+
+
 
 if __name__ == "__main__":
     main()
