@@ -6,11 +6,6 @@ import Quartz
 import os
 import sys
 
-try:
-    long
-except NameError:
-    long = int
-
 if sys.version_info[0] != 2:
     def buffer(value):
         if isinstance(value, bytes):
@@ -97,6 +92,8 @@ class TestCGContext (TestCase):
             fn = '/System/Library/CoreServices/DefaultDesktop.jpg'
             if not os.path.exists(fn):
                 fn = '/System/Library/Automator/Apply ColorSync Profile to Images.action/Contents/Resources/A-1075-normal.jpg'
+                if not os.path.exists(fn):
+                    fn = '/System/Library/CoreServices//RemoteManagement/ARDAgent.app/Contents/Resources/Lock.jpg'
 
             with open(fn, 'rb') as fp:
                 data = fp.read()
@@ -128,6 +125,8 @@ class TestCGContext (TestCase):
             CGContextDrawRadialGradient(context, gradient, (10, 15),
                     30, (50, 70), 99.5, kCGGradientDrawsAfterEndLocation)
 
+            CGContextDrawShading
+
             def evaluate(info, input, output):
                 return input * 4
 
@@ -238,6 +237,8 @@ class TestCGContext (TestCase):
             self.assertIsInstance(path, CGPathRef)
             CGContextAddPath(context, path)
 
+            CGContextReplacePathWithStrokedPath(context)
+
             self.assertResultHasType(CGContextIsPathEmpty, objc._C_BOOL)
             self.assertTrue(CGContextIsPathEmpty(context) is False)
 
@@ -247,6 +248,9 @@ class TestCGContext (TestCase):
             box = CGContextGetPathBoundingBox(context)
             self.assertIsInstance(box, CGRect)
 
+            p = CGContextCopyPath(context)
+            self.assertIsInstance(p, CGPathRef)
+
             self.assertResultHasType(CGContextPathContainsPoint, objc._C_BOOL)
             self.assertIsInstance(CGContextPathContainsPoint(context, pt, kCGPathStroke), bool)
 
@@ -272,7 +276,7 @@ class TestCGContext (TestCase):
             CGContextStrokeEllipseInRect(context, ((10, 10), (50, 30)))
 
             CGContextStrokeLineSegments(context,
-                    [ (0, 0), (10, 15), (15, 10) ], 3)
+                    [ (0, 0), (10, 15), (15, 10), (0, 0) ], 4)
             self.assertRaises(ValueError, CGContextStrokeLineSegments, context,
                     [ (0, 0), (10, 15), (15, 10) ], 4)
 
@@ -359,6 +363,11 @@ class TestCGContext (TestCase):
             self.assertArgHasType(CGContextSetShouldSmoothFonts, 1, objc._C_BOOL)
             CGContextSetShouldSmoothFonts(context, True)
 
+            self.assertArgHasType(CGContextSetAllowsFontSmoothing, 1, objc._C_BOOL)
+            CGContextSetAllowsFontSmoothing(context, True)
+
+            self.assertArgHasType(CGContextSetAllowsFontSubpixelQuantization, 1, objc._C_BOOL)
+            CGContextSetAllowsFontSubpixelQuantization(context, True)
 
             CGContextBeginTransparencyLayer(context, None)
             CGContextEndTransparencyLayer(context)
@@ -402,6 +411,8 @@ class TestCGContext (TestCase):
             fn = '/System/Library/CoreServices/DefaultDesktop.jpg'
             if not os.path.exists(fn):
                 fn = '/System/Library/Automator/Apply ColorSync Profile to Images.action/Contents/Resources/A-1075-normal.jpg'
+                if not os.path.exists(fn):
+                    fn = '/System/Library/CoreServices//RemoteManagement/ARDAgent.app/Contents/Resources/Lock.jpg'
 
             with open(fn, 'rb') as fp:
                 data = fp.read()
@@ -520,5 +531,8 @@ class TestCGContext (TestCase):
             if os.path.exists("/tmp/pyobjc.test.pdf"):
                 os.unlink("/tmp/pyobjc.test.pdf")
 
+    def testFunctions_n(self):
+         CGContextResetClip
+
 if __name__ == "__main__":
     main()
