@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 
-try:
-    long
-except NameError:
-    long = int
-
 class TestCGEvent (TestCase):
     def testTypes(self):
         self.assertIsCFType(CGEventRef)
@@ -89,10 +84,16 @@ class TestCGEvent (TestCase):
         self.assertArgHasType(CGEventPostToPSN, 0, b'n^{ProcessSerialNumber=II}')
         self.assertArgHasType(CGEventPostToPSN, 1, b'^{__CGEvent=}')
 
+    @min_os_level('10.11')
+    def testFunctions10_11(self):
+        CGEventPostToPid
+
 
     @expectedFailure
     def testMissing(self):
         self.fail("CGEventTapCreateForPSN")
+        self.fail("CGEventTapCreate")
+        self.fail("CGEventTapCreateForPid")
 
 
     def testFunctions(self):
@@ -141,5 +142,9 @@ class TestCGEvent (TestCase):
         v = CGEventGetUnflippedLocation(evt)
         self.assertIsInstance(v, CGPoint)
 
+    @min_os_level('10.13')
+    def testFunctions10_13(self):
+        CGEventCreateScrollWheelEvent2
+
 if __name__ == "__main__":
     main()
