@@ -2,16 +2,6 @@ from PyObjCTools.TestSupport import *
 
 import Quartz
 
-try:
-    long
-except NameError:
-    long = int
-
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestCGImageMetadata (TestCase):
     @min_os_level('10.8')
     def testTypes10_8(self):
@@ -104,6 +94,15 @@ class TestCGImageMetadata (TestCase):
         self.assertEqual(Quartz.kCGImageMetadataErrorConflictingArguments, 3)
         self.assertEqual(Quartz.kCGImageMetadataErrorPrefixConflict, 4)
 
+    @min_os_level('10.9')
+    def testConstants10_9(self):
+        self.assertIsInstance(Quartz.kCGImageMetadataNamespaceExifEX, unicode)
+        self.assertIsInstance(Quartz.kCGImageMetadataPrefixExifEX, unicode)
+
+    @min_os_level('10.13.4')
+    def testConstants10_13_4(self):
+        self.assertIsInstance(Quartz.kCGImageMetadataNamespaceIPTCExtension, unicode)
+        self.assertIsInstance(Quartz.kCGImageMetadataPrefixIPTCExtension, unicode)
 
 
 if __name__ == "__main__":
