@@ -3,15 +3,10 @@ from PyObjCTools.TestSupport import *
 from Quartz.CoreGraphics import *
 from Quartz import CoreGraphics
 
-try:
-    long
-except NameError:
-    long = int
-
 class TestCGPath (TestCase):
     def testTypes(self):
         self.assertIsCFType(CGPathRef)
-        self.failIf(hasattr(CoreGraphics, 'CGMutablePathRef'))
+        self.assertFalse(hasattr(CoreGraphics, 'CGMutablePathRef'))
 
     def testFunctions(self):
         self.assertIsInstance(CGPathGetTypeID(), (int, long))
@@ -20,6 +15,9 @@ class TestCGPath (TestCase):
         path = CGPathCreateMutable()
         self.assertIsInstance(path, CGPathRef)
 
+        path = CGPathCreateWithRect(CGRectMake(1,2,3,4), CGAffineTransformIdentity)
+        self.assertIsInstance(path, CGPathRef)
+
         self.assertResultIsCFRetained(CGPathCreateCopy)
         v = CGPathCreateCopy(path)
         self.assertIsInstance(v, CGPathRef)
@@ -103,7 +101,7 @@ class TestCGPath (TestCase):
         v = CGPathContainsPoint(path, transform, (
             CGRectGetMidX(box),
             CGRectGetMidY(box)), True)
-        self.assertTrue(v is True)
+        self.assertTrue(v is True or v is False)
 
         v = CGPathContainsPoint(path, transform, (
             box.origin.x - 1,
@@ -123,7 +121,7 @@ class TestCGPath (TestCase):
             self.assertIsInstance(element.points[0], CGPoint)
 
         CGPathApply(path, info, applier)
-        self.failIfEqual(l[0], 0)
+        self.assertNotEqual(l[0], 0)
 
     @min_os_level('10.6')
     def testFunctions10_6(self):
@@ -174,7 +172,30 @@ class TestCGPath (TestCase):
         CGPathMoveToPoint(path, transform, 10, 30)
         CGPathAddRelativeArc(path, transform, 80, 90, 22.5, 33.0, 5.0)
 
+    @min_os_level('10.9')
+    def testFunctions10_9(self):
+
+        path = CGPathCreateMutable()
+        self.assertIsInstance(path, CGPathRef)
+
+        transform = CGAffineTransformIdentity
+
+        self.assertResultIsCFRetained(CGPathCreateWithRoundedRect)
+        v = CGPathCreateWithRoundedRect(CGRectMake(100, 200, 300, 400), 2, 4, transform)
+        self.assertIsInstance(v, CGPathRef)
+
+        CGPathAddRoundedRect(path, transform, CGRectMake(100, 200, 300, 400), 2, 3)
+
+
     def testConstants(self):
+        self.assertEqual(kCGLineJoinMiter, 0)
+        self.assertEqual(kCGLineJoinRound, 1)
+        self.assertEqual(kCGLineJoinBevel, 2)
+
+        self.assertEqual(kCGLineCapButt, 0)
+        self.assertEqual(kCGLineCapRound, 1)
+        self.assertEqual(kCGLineCapSquare, 2)
+
         self.assertEqual(kCGPathElementMoveToPoint, 0)
         self.assertEqual(kCGPathElementAddLineToPoint, 1)
         self.assertEqual(kCGPathElementAddQuadCurveToPoint, 2)
