@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 
 class TestImageKitDeprecatedHelper (NSObject):
     def numberOfCellsInImageBrowser_(self, b): return 1
@@ -31,6 +26,7 @@ class TestImageKitDeprecated (TestCase):
 
         self.assertIsInstance(IKPictureTakerShowAddressBookPicture, unicode)
         self.assertIsInstance(IKPictureTakerShowEmptyPicture, unicode)
+        self.assertIsInstance(IKPictureTakerCropAreaSizeKey, unicode)
 
     @min_os_level('10.5')
     def testMethods(self):
@@ -46,7 +42,7 @@ class TestImageKitDeprecated (TestCase):
         self.assertResultIsBOOL(TestImageKitDeprecatedHelper.imageBrowser_moveCellsAtIndexes_toIndex_)
         self.assertArgHasType(TestImageKitDeprecatedHelper.imageBrowser_moveCellsAtIndexes_toIndex_, 2, objc._C_NSUInteger)
 
-    @min_os_level('10.6')
+    @os_level_between('10.6', '10.13')
     def testConstants10_6(self):
         self.assertIsInstance(IKImageBrowserCellLayerTypeBackground, unicode)
         self.assertIsInstance(IKImageBrowserCellLayerTypeForeground, unicode)
