@@ -2,11 +2,6 @@
 from PyObjCTools.TestSupport import *
 from Quartz.PDFKit import *
 
-try:
-    unicode
-except NameError:
-    unicode = str
-
 class TestPDFViewHelper (NSObject):
     def PDFViewWillChangeScaleFactor_toScale_(self, f, s): return 1.0
     def PDFViewWillClickOnLink_withURL_(self, s, u): pass
@@ -32,6 +27,7 @@ class TestPDFView (TestCase):
         self.assertEqual(kPDFTextFieldArea, 32)
         self.assertEqual(kPDFIconArea, 64)
         self.assertEqual(kPDFPopupArea, 128)
+        self.assertEqual(kPDFImageArea, 256)
 
         self.assertIsInstance(PDFViewDocumentChangedNotification, unicode)
         self.assertIsInstance(PDFViewChangedHistoryNotification, unicode)
@@ -40,6 +36,10 @@ class TestPDFView (TestCase):
         self.assertIsInstance(PDFViewAnnotationHitNotification, unicode)
         self.assertIsInstance(PDFViewCopyPermissionNotification, unicode)
         self.assertIsInstance(PDFViewPrintPermissionNotification, unicode)
+        self.assertIsInstance(PDFViewVisiblePagesChangedNotification, unicode)
+
+        self.assertEqual(kPDFDisplayDirectionVertical, 0)
+        self.assertEqual(kPDFDisplayDirectionHorizontal, 1)
 
     @min_os_level('10.5')
     def testConstants10_5(self):
@@ -90,6 +90,19 @@ class TestPDFView (TestCase):
         self.assertResultIsBOOL(PDFView.enableDataDetectors)
         self.assertArgIsBOOL(PDFView.setEnableDataDetectors_, 0)
 
+    @min_os_level('10.13')
+    def testMethods10_13(self):
+        self.assertResultIsBOOL(PDFView.displaysRTL)
+        self.assertArgIsBOOL(PDFView.setDisplaysRTL_, 0)
+
+        self.assertResultIsBOOL(PDFView.acceptsDraggedFiles)
+        self.assertArgIsBOOL(PDFView.setAcceptsDraggedFiles_, 0)
+
+    @min_os_level('10.14')
+    def testMethods10_14(self):
+        self.assertResultIsBOOL(PDFView.pageShadowsEnabled)
+        self.assertArgIsBOOL(PDFView.enablePageShadows_, 0)
+
     def testProtocols(self):
         #self.assertIsInstance(protocols.PDFViewDelegate, objc.informal_protocol)
 
